Class: FiberAudit::Static::Rules::BlockingSubprocess

Inherits:
Base
  • Object
show all
Defined in:
lib/fiber_audit/static/rules/blocking_subprocess.rb

Constant Summary collapse

TARGETS =
OperationVocabulary::FA1001_TARGETS
BARE_KERNEL_METHODS =
OperationVocabulary::FA1001_KERNEL_METHODS
MESSAGE =
'Subprocess operation may block the thread running the fiber scheduler.'
REMEDIATION =
'Move long-running subprocess work outside the request path, or verify scheduler behaviour under load.'

Constants inherited from Base

FiberAudit::Static::Rules::Base::CONTEXT_CEILING

Instance Method Summary collapse

Methods inherited from Base

confidence, default_confidence, default_severity, description, id, #initialize, severity

Constructor Details

This class inherits a constructor from FiberAudit::Static::Rules::Base

Instance Method Details

#analyze(call_sites:) ⇒ Object



24
25
26
27
28
29
30
# File 'lib/fiber_audit/static/rules/blocking_subprocess.rb', line 24

def analyze(call_sites:)
  call_sites.filter_map do |site|
    next unless (match = match_call_site(site))

    build_finding(site, match)
  end
end